@@ -1,12 +1,12 @@
 ﻿# encoding=utf-8
 import logging
-import platform
 import subprocess  # nosec
 import time
 from collections import abc
+from operator import attrgetter
 from pathlib import Path
 from threading import Lock
-from typing import Iterable, Iterator, List, MutableSequence, Sequence, Set, Union
+from typing import Iterable, List, MutableSequence, Optional, Sequence, Set, Union
 
 import requests
 from _pytest.fixtures import FixtureRequest  # type: ignore
@@ -15,13 +15,12 @@ from requests import RequestException
 
 from mbtest.imposters import Imposter
 from mbtest.imposters.imposters import Request
-
-DEFAULT_MB_PATH = Path("node_modules") / ".bin"
-DEFAULT_MB_NAME = Path("mb.cmd" if platform.system() == "Windows" else "mb")  # pragma: no mutate
-DEFAULT_MB_EXECUTABLE = str(DEFAULT_MB_PATH / DEFAULT_MB_NAME)
+from mbtest.util import find_mountebank_executable
 
 logger = logging.getLogger(__name__)
 
+DEFAULT_MB_EXECUTABLE = find_mountebank_executable()
+
 
 def mock_server(
     request: FixtureRequest,
@@ -140,26 +139,40 @@ class MountebankServer:
         """Add imposters to Mountebank server.
 
         :param definition: One or more Imposters.
-        :type definition: Imposter or list(Imposter)
         """
         if isinstance(definition, abc.Iterable):
             for imposter in definition:
                 self.add_imposters(imposter)
         else:
-            json = definition.as_structure()
-            post = requests.post(self.server_url, json=json, timeout=10)
-            post.raise_for_status()
-            definition.attach(self.host, post.json()["port"], self.server_url)
-            self._running_imposters.append(definition)
+            self.add_impostor(definition)
+
+    def add_impostor(self, definition):
+        """Add single imposter to Mountebank server.
+
+        :param definition: One or more Imposters."""
+        json = definition.as_structure()
+        post = requests.post(self.server_url, json=json, timeout=10)
+        post.raise_for_status()
+        definition.attach(self.host, post.json()["port"], self.server_url)
+        self._running_imposters.append(definition)
 
     def delete_imposters(self) -> None:
+        """Delete all impostors from server."""
         while self._running_imposters:
-            imposter = self._running_imposters.pop()
-            requests.delete(imposter.configuration_url).raise_for_status()
+            self.delete_impostor(self._running_imposters[0])
 
-    def get_actual_requests(self) -> Iterable[Request]:
+    def delete_impostor(self, imposter):
+        """Delete impostor from server."""
+        requests.delete(imposter.configuration_url).raise_for_status()
+        self._running_imposters = [
+            i for i in self._running_imposters if i.configuration_url != imposter.configuration_url
+        ]
+
+    def get_actual_requests(self) -> Sequence[Request]:
+        actual_requests: MutableSequence[Request] = []
         for imposter in self._running_imposters:
-            yield from imposter.get_actual_requests()
+            actual_requests += imposter.get_actual_requests()
+        return actual_requests
 
     @property
     def server_url(self) -> furl:
@@ -167,12 +180,28 @@ class MountebankServer:
             scheme=self.scheme, host=self.host, port=self.server_port, path=self.imposters_path
         )
 
-    def query_all_imposters(self) -> Iterator[Imposter]:
+    def query_all_imposters(self) -> Sequence[Imposter]:
         """Yield all imposters running on the server, including those defined elsewhere."""
         server_info = requests.get(self.server_url)
-        imposters = server_info.json()["imposters"]
-        for imposter in imposters:
-            yield Imposter.from_structure(requests.get(imposter["_links"]["self"]["href"]).json())
+        imposters_structure = server_info.json()["imposters"]
+        all_imposters: MutableSequence[Imposter] = []
+        for imposter_structure in imposters_structure:
+            impostor_url = imposter_structure["_links"]["self"]["href"]
+            imposter = Imposter.from_structure(requests.get(impostor_url).json())
+            imposter.host = self.host
+            imposter.server_url = self.server_url
+            all_imposters.append(imposter)
+        return sorted(all_imposters, key=attrgetter("port"))
+
+    def import_running_imposters(self) -> None:
+        """Replaces all running imposters with those defined on the server"""
+        self._running_imposters = []
+        for imposter in self.query_all_imposters():
+            self._running_imposters.append(imposter)
+
+    def get_running_imposters(self) -> Sequence[Imposter]:
+        """Returns all imposters that the instance is aware of"""
+        return self._running_imposters
 
 
 class ExecutingMountebankServer(MountebankServer):
@@ -227,7 +256,7 @@ class ExecutingMountebankServer(MountebankServer):
                 raise MountebankPortInUseException(f"Already running on port {self.server_port}.")
             try:
                 options = self._build_options(port, debug, allow_injection, local_only, data_dir)
-                self.mb_process = subprocess.Popen([executable] + options)  # nosec
+                self.mb_process = subprocess.Popen([str(executable)] + options)  # nosec
                 self._await_start(timeout)
                 self.running.add(port)
                 logger.info(
@@ -242,8 +271,8 @@ class ExecutingMountebankServer(MountebankServer):
 
     @staticmethod
     def _build_options(
-        port: int, debug: bool, allow_injection: bool, local_only: bool, data_dir: Union[str, None]
-    ):
+        port: int, debug: bool, allow_injection: bool, local_only: bool, data_dir: Optional[str]
+    ) -> List[str]:
         options: List[str] = ["start", "--port", str(port)]
         if debug:
             options.append("--debug")
